# rulm

[![Build Status](https://travis-ci.org/IlyaGusev/rulm.svg?branch=master)](https://travis-ci.org/IlyaGusev/rulm)
[![Code Climate](https://codeclimate.com/github/IlyaGusev/rulm/badges/gpa.svg)](https://codeclimate.com/github/IlyaGusev/rulm)
[![codecov](https://codecov.io/gh/IlyaGusev/rulm/branch/master/graph/badge.svg)](https://codecov.io/gh/IlyaGusev/rulm)

Language models for Russian language: implementation and comparison
